pykwic
===========

KWIC Library for unicode text using Suffix Array.

Based on *esa.hxx* and *sais.hxx*.

Authors & Contributors
----------------------

* Shunsuke Aihara - http://argmax.jp

This module is based on *esa.hxx* by Daisuke Okanohara and *sais.hxx* by Yuta Mori.

This module is prepared with reference to *Minise* by Daisuke Okanohara.

License
=======

Wrapper code is licensed under MIT License.

Bundled *esa.hxx* and *sais.hxx* are licensed under MIT License.
